@@ -1,4 +1,4 @@
 from stringcolor import * 
 
 def test():
-  print(cs("you good", 0x0000ff))
\ No newline at end of file
+  print(cs("you good", "#0000ff"))
\ No newline at end of file
